<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('customer_complaint');

// 记录访问日志
record_log('访问投诉管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加投诉
    if ($_POST['action'] == 'add') {
        $complaint_no = 'CP' . date('YmdHis') . rand(100, 999); // 生成投诉编号
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : null;
        $guest_name = isset($_POST['guest_name']) ? trim($_POST['guest_name']) : '';
        $contact = isset($_POST['contact']) ? trim($_POST['contact']) : '';
        $booking_no = isset($_POST['booking_no']) ? trim($_POST['booking_no']) : '';
        $complaint_type = isset($_POST['complaint_type']) ? intval($_POST['complaint_type']) : 1;
        $complaint_content = isset($_POST['complaint_content']) ? trim($_POST['complaint_content']) : '';
        $status = 1; // 待处理

        if (empty($guest_name) || empty($contact) || empty($complaint_content)) {
            $error = '请填写完整投诉信息！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    INSERT INTO guest_complaints (
                        complaint_no, member_id, guest_name, contact, booking_no, 
                        complaint_type, complaint_content, status
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)
                ");
                $result = $stmt->execute([
                    $complaint_no,
                    $member_id,
                    $guest_name,
                    $contact,
                    $booking_no,
                    $complaint_type,
                    $complaint_content,
                    $status
                ]);

                if ($result) {
                    record_log("添加客户投诉：{$guest_name}，投诉编号：{$complaint_no}");
                    $success = '投诉记录添加成功！';
                } else {
                    $error = '投诉记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 处理投诉
    elseif ($_POST['action'] == 'handle') {
        $complaint_id = isset($_POST['complaint_id']) ? intval($_POST['complaint_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 2;
        $handle_content = isset($_POST['handle_content']) ? trim($_POST['handle_content']) : '';

        if ($complaint_id <= 0) {
            $error = '无效的投诉ID！';
        } elseif (empty($handle_content)) {
            $error = '请填写处理内容！';
        } else {
            try {
                // 获取当前用户ID
                $handler_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;

                $stmt = $pdo->prepare("
                    UPDATE guest_complaints 
                    SET status = ?, handle_content = ?, handler_id = ?, handle_time = NOW() 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$status, $handle_content, $handler_id, $complaint_id]);

                if ($result) {
                    $status_text = $status == 2 ? '处理中' : ($status == 3 ? '已解决' : '未解决');
                    record_log("处理客户投诉，ID：{$complaint_id}，状态：{$status_text}");
                    $success = '投诉处理成功！';
                } else {
                    $error = '投诉处理失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除投诉
    elseif ($_POST['action'] == 'delete') {
        $complaint_id = isset($_POST['complaint_id']) ? intval($_POST['complaint_id']) : 0;

        if ($complaint_id <= 0) {
            $error = '无效的投诉ID！';
        } else {
            try {
                $stmt = $pdo->prepare("DELETE FROM guest_complaints WHERE id = ?");
                $result = $stmt->execute([$complaint_id]);

                if ($result) {
                    record_log("删除客户投诉，ID：{$complaint_id}");
                    $success = '投诉记录删除成功！';
                } else {
                    $error = '投诉记录删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';
// 判断是否显示处理表单
$handle_complaint = null;
if (isset($_GET['handle']) && intval($_GET['handle']) > 0) {
    $complaint_id = intval($_GET['handle']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM guest_complaints WHERE id = ?");
        $stmt->execute([$complaint_id]);
        $handle_complaint = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取投诉详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_complaint_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取会员列表，用于添加投诉时选择
try {
    $stmt = $pdo->query("SELECT id, member_no, name, mobile FROM guest_members ORDER BY id DESC");
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
    $members = [];
}

// 获取投诉列表
try {
    $stmt = $pdo->query("
        SELECT c.*, m.name as member_name, u.username as handler_name
        FROM guest_complaints c
        LEFT JOIN guest_members m ON c.member_id = m.id
        LEFT JOIN sys_users u ON c.handler_id = u.id
        ORDER BY c.create_time DESC
    ");
    $complaints = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取投诉列表失败：' . $e->getMessage();
    $complaints = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>投诉管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 投诉管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$handle_complaint): ?>
                    <a href="complaint.php?show_form=add" class="btn btn-add">添加投诉</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加投诉表单 -->
                <h3>添加投诉</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="member_id">会员选择（可选）：</label>
                            <select id="member_id" name="member_id">
                                <option value="">-- 非会员投诉 --</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>" data-name="<?php echo $member['name']; ?>" data-mobile="<?php echo $member['mobile']; ?>">
                                        <?php echo $member['name']; ?> (<?php echo $member['member_no']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <p class="form-hint">选择会员将自动填充客人姓名和联系方式</p>
                        </div>

                        <div class="form-group">
                            <label for="guest_name">客人姓名：</label>
                            <input type="text" id="guest_name" name="guest_name" required>
                        </div>

                        <div class="form-group">
                            <label for="contact">联系方式：</label>
                            <input type="text" id="contact" name="contact" required>
                        </div>

                        <div class="form-group">
                            <label for="booking_no">预订号（可选）：</label>
                            <input type="text" id="booking_no" name="booking_no">
                        </div>

                        <div class="form-group">
                            <label for="complaint_type">投诉类型：</label>
                            <select id="complaint_type" name="complaint_type" required>
                                <option value="1">客房设施</option>
                                <option value="2">服务态度</option>
                                <option value="3">噪音干扰</option>
                                <option value="4">卫生问题</option>
                                <option value="5">餐饮相关</option>
                                <option value="6">其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="complaint_content">投诉内容：</label>
                            <textarea id="complaint_content" name="complaint_content" rows="5" required></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="complaint.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($handle_complaint): ?>
                <!-- 处理投诉表单 -->
                <h3>处理投诉 - <?php echo $handle_complaint['complaint_no']; ?></h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="handle">
                        <input type="hidden" name="complaint_id" value="<?php echo $handle_complaint['id']; ?>">

                        <div class="complaint-details">
                            <p><strong>客人姓名：</strong> <?php echo $handle_complaint['guest_name']; ?></p>
                            <p><strong>联系方式：</strong> <?php echo $handle_complaint['contact']; ?></p>
                            <p><strong>投诉内容：</strong> <?php echo nl2br($handle_complaint['complaint_content']); ?></p>
                        </div>

                        <div class="form-group">
                            <label for="status">处理状态：</label>
                            <select id="status" name="status" required>
                                <option value="2" <?php echo $handle_complaint['status'] == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $handle_complaint['status'] == 3 ? 'selected' : ''; ?>>已解决</option>
                                <option value="4" <?php echo $handle_complaint['status'] == 4 ? 'selected' : ''; ?>>未解决</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="handle_content">处理内容：</label>
                            <textarea id="handle_content" name="handle_content" rows="5" required><?php echo $handle_complaint['handle_content']; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="complaint.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <h3>投诉列表</h3>
            <!-- 投诉列表 -->
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>投诉编号</th>
                            <th>客人姓名</th>
                            <th>联系方式</th>
                            <th>投诉类型</th>
                            <th>投诉时间</th>
                            <th>状态</th>
                            <th>处理人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($complaints as $complaint): ?>
                            <tr>
                                <td><?php echo $complaint['id']; ?></td>
                                <td><?php echo $complaint['complaint_no']; ?></td>
                                <td>
                                    <?php echo $complaint['guest_name']; ?>
                                    <?php if ($complaint['member_id']): ?>
                                        <span class="badge"><?php echo $complaint['member_name']; ?></span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo $complaint['contact']; ?></td>
                                <td>
                                    <?php
                                    $complaint_types = [
                                        1 => '客房设施',
                                        2 => '服务态度',
                                        3 => '噪音干扰',
                                        4 => '卫生问题',
                                        5 => '餐饮相关',
                                        6 => '其他'
                                    ];
                                    echo $complaint_types[$complaint['complaint_type']] ?? '未知';
                                    ?>
                                </td>
                                <td><?php echo date('Y-m-d H:i', strtotime($complaint['create_time'])); ?></td>
                                <td>
                                    <?php
                                    switch ($complaint['status']) {
                                        case 1:
                                            echo '<span class="status-warning">待处理</span>';
                                            break;
                                        case 2:
                                            echo '<span class="status-processing">处理中</span>';
                                            break;
                                        case 3:
                                            echo '<span class="status-active">已解决</span>';
                                            break;
                                        case 4:
                                            echo '<span class="status-inactive">未解决</span>';
                                            break;
                                        default:
                                            echo '<span>未知</span>';
                                    }
                                    ?>
                                </td>
                                <td><?php echo $complaint['handler_name'] ?? '-'; ?></td>
                                <td>
                                    <a href="complaint.php?view=<?php echo $complaint['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                    <?php if ($complaint['status'] < 3): ?>
                                        <a href="complaint.php?handle=<?php echo $complaint['id']; ?>" class="btn btn-sm btn-edit">处理</a>
                                    <?php endif; ?>

                                    <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此投诉记录吗？此操作不可恢复！');">
                                        <input type="hidden" name="action" value="delete">
                                        <input type="hidden" name="complaint_id" value="<?php echo $complaint['id']; ?>">
                                        <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                    </form>
                                </td>
                            </tr>
                            <?php if ($view_complaint_id == $complaint['id']): ?>
                                <tr id="complaint-<?php echo $complaint['id']; ?>">
                                    <td colspan="9" class="details-row">
                                        <div class="complaint-details">
                                            <div class="complaint-content">
                                                <h4>投诉内容：</h4>
                                                <p><?php echo nl2br($complaint['complaint_content']); ?></p>
                                            </div>
                                            <?php if ($complaint['booking_no']): ?>
                                                <div class="complaint-booking">
                                                    <h4>关联预订号：</h4>
                                                    <p><?php echo $complaint['booking_no']; ?></p>
                                                </div>
                                            <?php endif; ?>
                                            <?php if ($complaint['handle_content']): ?>
                                                <div class="complaint-handle">
                                                    <h4>处理内容：</h4>
                                                    <p><?php echo nl2br($complaint['handle_content']); ?></p>
                                                    <p class="handle-info">
                                                        处理人：<?php echo $complaint['handler_name'] ?? '未知'; ?> |
                                                        处理时间：<?php echo $complaint['handle_time'] ? date('Y-m-d H:i', strtotime($complaint['handle_time'])) : '-'; ?>
                                                    </p>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>