<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_bill');

// 记录访问日志
record_log('访问账单管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加账单
    if ($_POST['action'] == 'add') {
        $payment_no = 'PAY' . date('YmdHis') . rand(100, 999); // 生成支付单号
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $booking_id = isset($_POST['booking_id']) && $_POST['booking_id'] > 0 ? intval($_POST['booking_id']) : null;
        $checkin_id = isset($_POST['checkin_id']) && $_POST['checkin_id'] > 0 ? intval($_POST['checkin_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? intval($_POST['payment_method']) : 1;
        $payment_time = isset($_POST['payment_time']) ? trim($_POST['payment_time']) : date('Y-m-d H:i:s');
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($amount <= 0) {
            $error = '金额必须大于0！';
        } elseif ($type != 1 && $type != 2) {
            $error = '请选择有效的账单类型！';
        } elseif (!$booking_id && !$checkin_id) {
            $error = '请关联预订单或入住单！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    INSERT INTO finance_payments (
                        payment_no, type, booking_id, checkin_id, amount, payment_method, 
                        payment_time, status, operator_id, remark
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");
                $result = $stmt->execute([
                    $payment_no,
                    $type,
                    $booking_id,
                    $checkin_id,
                    $amount,
                    $payment_method,
                    $payment_time,
                    $status,
                    $_SESSION['user_id'], // 当前登录用户ID
                    $remark
                ]);

                if ($result) {
                    record_log("添加账单：{$payment_no}，金额：{$amount}");
                    $success = '账单添加成功！';
                } else {
                    $error = '账单添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑账单
    elseif ($_POST['action'] == 'edit') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;
        $booking_id = isset($_POST['booking_id']) && $_POST['booking_id'] > 0 ? intval($_POST['booking_id']) : null;
        $checkin_id = isset($_POST['checkin_id']) && $_POST['checkin_id'] > 0 ? intval($_POST['checkin_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? intval($_POST['payment_method']) : 1;
        $payment_time = isset($_POST['payment_time']) ? trim($_POST['payment_time']) : date('Y-m-d H:i:s');
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($payment_id <= 0) {
            $error = '无效的账单ID！';
        } elseif ($amount <= 0) {
            $error = '金额必须大于0！';
        } elseif (!$booking_id && !$checkin_id) {
            $error = '请关联预订单或入住单！';
        } else {
            try {
                // 获取原始支付记录，用于日志记录
                $stmt = $pdo->prepare("SELECT payment_no, type FROM finance_payments WHERE id = ?");
                $stmt->execute([$payment_id]);
                $original = $stmt->fetch();

                if (!$original) {
                    $error = '账单不存在！';
                } else {
                    // 不允许修改支付类型，只允许修改其他信息
                    $stmt = $pdo->prepare("
                        UPDATE finance_payments 
                        SET booking_id = ?, checkin_id = ?, amount = ?, payment_method = ?, 
                            payment_time = ?, status = ?, remark = ? 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $booking_id,
                        $checkin_id,
                        $amount,
                        $payment_method,
                        $payment_time,
                        $status,
                        $remark,
                        $payment_id
                    ]);

                    if ($result) {
                        record_log("编辑账单：{$original['payment_no']}，金额：{$amount}");
                        $success = '账单更新成功！';
                    } else {
                        $error = '账单更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 取消账单
    elseif ($_POST['action'] == 'cancel') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;
        $cancel_reason = isset($_POST['cancel_reason']) ? trim($_POST['cancel_reason']) : '';

        if ($payment_id <= 0) {
            $error = '无效的账单ID！';
        } else {
            try {
                // 获取原始支付记录
                $stmt = $pdo->prepare("SELECT payment_no, status FROM finance_payments WHERE id = ?");
                $stmt->execute([$payment_id]);
                $payment = $stmt->fetch();

                if (!$payment) {
                    $error = '账单不存在！';
                } elseif ($payment['status'] == 3) {
                    $error = '账单已被取消！';
                } else {
                    $stmt = $pdo->prepare("UPDATE finance_payments SET status = 3, remark = CONCAT(remark, '；取消原因：', ?) WHERE id = ?");
                    $result = $stmt->execute([
                        $cancel_reason,
                        $payment_id
                    ]);

                    if ($result) {
                        record_log("取消账单：{$payment['payment_no']}，原因：{$cancel_reason}");
                        $success = '账单取消成功！';
                    } else {
                        $error = '账单取消失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除账单
    elseif ($_POST['action'] == 'delete') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;

        if ($payment_id <= 0) {
            $error = '无效的账单ID！';
        } else {
            try {
                // 获取账单信息，用于日志记录
                $stmt = $pdo->prepare("SELECT payment_no FROM finance_payments WHERE id = ?");
                $stmt->execute([$payment_id]);
                $payment = $stmt->fetch();

                if (!$payment) {
                    $error = '账单不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM finance_payments WHERE id = ?");
                    $result = $stmt->execute([$payment_id]);

                    if ($result) {
                        record_log("删除账单：{$payment['payment_no']}");
                        $success = '账单删除成功！';
                    } else {
                        $error = '账单删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取账单详情
$edit_payment = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $payment_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM finance_payments WHERE id = ?");
        $stmt->execute([$payment_id]);
        $edit_payment = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取账单详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_payment_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取预订单列表（用于关联选择）
try {
    $stmt = $pdo->query("
        SELECT id, booking_no, guest_name, total_amount 
        FROM booking_orders 
        WHERE status NOT IN (3, 5) 
        ORDER BY id DESC
    ");
    $bookings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预订单列表失败：' . $e->getMessage();
    $bookings = [];
}

// 获取入住单列表（用于关联选择）
try {
    $stmt = $pdo->query("
        SELECT id, checkin_no, guest_name, total_amount 
        FROM checkin_orders 
        WHERE status != 3 
        ORDER BY id DESC
    ");
    $checkins = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取入住单列表失败：' . $e->getMessage();
    $checkins = [];
}

// 获取筛选条件
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
$filter_payment_method = isset($_GET['payment_method']) ? intval($_GET['payment_method']) : 0;
$filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-7 days'));
$filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 构建查询条件
$where_clauses = ["payment_time BETWEEN ? AND ?"];
$params = [$filter_start_date . ' 00:00:00', $filter_end_date . ' 23:59:59'];

if ($filter_type > 0) {
    $where_clauses[] = "type = ?";
    $params[] = $filter_type;
}

if ($filter_status > 0) {
    $where_clauses[] = "status = ?";
    $params[] = $filter_status;
}

if ($filter_payment_method > 0) {
    $where_clauses[] = "payment_method = ?";
    $params[] = $filter_payment_method;
}

$where_sql = implode(" AND ", $where_clauses);

// 获取所有账单
try {
    $stmt = $pdo->prepare("
        SELECT p.*, 
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.booking_no
                   WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                   ELSE NULL
               END AS order_no,
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.guest_name
                   WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                   ELSE NULL
               END AS guest_name,
               u.username as operator_name
        FROM finance_payments p
        LEFT JOIN booking_orders b ON p.booking_id = b.id
        LEFT JOIN checkin_orders c ON p.checkin_id = c.id
        LEFT JOIN sys_users u ON p.operator_id = u.id
        WHERE {$where_sql}
        ORDER BY p.payment_time DESC
    ");
    $stmt->execute($params);
    $payments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取账单列表失败：' . $e->getMessage();
    $payments = [];
}

// 计算总收入和总支出
$total_income = 0;
$total_expense = 0;
foreach ($payments as $payment) {
    if ($payment['type'] == 1 && $payment['status'] == 1) {
        $total_income += $payment['amount'];
    } elseif ($payment['type'] == 2 && $payment['status'] == 2) {
        $total_expense += $payment['amount'];
    }
}

// 支付方式列表
$payment_methods = [
    1 => '现金',
    2 => '信用卡',
    3 => '微信',
    4 => '支付宝',
    5 => '银行转账'
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>账单管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>账单管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 账单管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_payment): ?>
                    <a href="bill.php?show_form=add" class="btn btn-primary">添加账单</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加账单表单 -->
                <h3>添加账单</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="type">账单类型：</label>
                            <select id="type" name="type" required>
                                <option value="1">收款</option>
                                <option value="2">退款</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="booking_id">关联预订单：</label>
                            <select id="booking_id" name="booking_id">
                                <option value="0">不关联预订单</option>
                                <?php foreach ($bookings as $booking): ?>
                                    <option value="<?php echo $booking['id']; ?>"><?php echo $booking['booking_no']; ?> - <?php echo $booking['guest_name']; ?> (￥<?php echo $booking['total_amount']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="checkin_id">关联入住单：</label>
                            <select id="checkin_id" name="checkin_id">
                                <option value="0">不关联入住单</option>
                                <?php foreach ($checkins as $checkin): ?>
                                    <option value="<?php echo $checkin['id']; ?>"><?php echo $checkin['checkin_no']; ?> - <?php echo $checkin['guest_name']; ?> (￥<?php echo $checkin['total_amount']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">支付方式：</label>
                            <select id="payment_method" name="payment_method" required>
                                <?php foreach ($payment_methods as $key => $method): ?>
                                    <option value="<?php echo $key; ?>"><?php echo $method; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="payment_time">支付时间：</label>
                            <input type="datetime-local" id="payment_time" name="payment_time" value="<?php echo date('Y-m-d\TH:i'); ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">已支付</option>
                                <option value="2">已退款</option>
                                <option value="3">已取消</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="bill.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_payment): ?>
                <!-- 编辑账单表单 -->
                <h3>编辑账单</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="payment_id" value="<?php echo $edit_payment['id']; ?>">

                        <div class="form-group">
                            <label for="payment_no">支付单号：</label>
                            <input type="text" id="payment_no" value="<?php echo $edit_payment['payment_no']; ?>" readonly>
                        </div>

                        <div class="form-group">
                            <label for="type">账单类型：</label>
                            <select id="type" disabled>
                                <option value="1" <?php echo $edit_payment['type'] == 1 ? 'selected' : ''; ?>>收款</option>
                                <option value="2" <?php echo $edit_payment['type'] == 2 ? 'selected' : ''; ?>>退款</option>
                            </select>
                            <p class="form-hint">账单类型不可修改</p>
                        </div>

                        <div class="form-group">
                            <label for="booking_id">关联预订单：</label>
                            <select id="booking_id" name="booking_id">
                                <option value="0">不关联预订单</option>
                                <?php foreach ($bookings as $booking): ?>
                                    <option value="<?php echo $booking['id']; ?>" <?php echo $edit_payment['booking_id'] == $booking['id'] ? 'selected' : ''; ?>><?php echo $booking['booking_no']; ?> - <?php echo $booking['guest_name']; ?> (￥<?php echo $booking['total_amount']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="checkin_id">关联入住单：</label>
                            <select id="checkin_id" name="checkin_id">
                                <option value="0">不关联入住单</option>
                                <?php foreach ($checkins as $checkin): ?>
                                    <option value="<?php echo $checkin['id']; ?>" <?php echo $edit_payment['checkin_id'] == $checkin['id'] ? 'selected' : ''; ?>><?php echo $checkin['checkin_no']; ?> - <?php echo $checkin['guest_name']; ?> (￥<?php echo $checkin['total_amount']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0.01" value="<?php echo $edit_payment['amount']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">支付方式：</label>
                            <select id="payment_method" name="payment_method" required>
                                <?php foreach ($payment_methods as $key => $method): ?>
                                    <option value="<?php echo $key; ?>" <?php echo $edit_payment['payment_method'] == $key ? 'selected' : ''; ?>><?php echo $method; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="payment_time">支付时间：</label>
                            <input type="datetime-local" id="payment_time" name="payment_time" value="<?php echo date('Y-m-d\TH:i', strtotime($edit_payment['payment_time'])); ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_payment['status'] == 1 ? 'selected' : ''; ?>>已支付</option>
                                <option value="2" <?php echo $edit_payment['status'] == 2 ? 'selected' : ''; ?>>已退款</option>
                                <option value="3" <?php echo $edit_payment['status'] == 3 ? 'selected' : ''; ?>>已取消</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"><?php echo $edit_payment['remark']; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="bill.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_payment): ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="type">账单类型：</label>
                                <select id="type" name="type">
                                    <option value="0">全部类型</option>
                                    <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>收款</option>
                                    <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>退款</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="0">全部状态</option>
                                    <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>已支付</option>
                                    <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已退款</option>
                                    <option value="3" <?php echo $filter_status == 3 ? 'selected' : ''; ?>>已取消</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="payment_method">支付方式：</label>
                                <select id="payment_method" name="payment_method">
                                    <option value="0">全部方式</option>
                                    <?php foreach ($payment_methods as $key => $method): ?>
                                        <option value="<?php echo $key; ?>" <?php echo $filter_payment_method == $key ? 'selected' : ''; ?>><?php echo $method; ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="bill.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计信息 -->
                <div class="summary-box">
                    <div class="summary-item">
                        <span class="summary-label">总收入：</span>
                        <span class="summary-value">￥<?php echo number_format($total_income, 2); ?></span>
                    </div>
                    <div class="summary-item">
                        <span class="summary-label">总支出：</span>
                        <span class="summary-value">￥<?php echo number_format($total_expense, 2); ?></span>
                    </div>
                    <div class="summary-item">
                        <span class="summary-label">净收入：</span>
                        <span class="summary-value">￥<?php echo number_format($total_income - $total_expense, 2); ?></span>
                    </div>
                </div>

                <!-- 账单列表 -->
                <h3>账单列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>支付单号</th>
                                <th>关联订单</th>
                                <th>客人</th>
                                <th>类型</th>
                                <th>金额(元)</th>
                                <th>支付方式</th>
                                <th>支付时间</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($payments as $payment): ?>
                                <tr>
                                    <td><?php echo $payment['payment_no']; ?></td>
                                    <td><?php echo $payment['order_no'] ?: '-'; ?></td>
                                    <td><?php echo $payment['guest_name'] ?: '-'; ?></td>
                                    <td>
                                        <?php if ($payment['type'] == 1): ?>
                                            <span class="status-active">收款</span>
                                        <?php else: ?>
                                            <span class="status-inactive">退款</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo number_format($payment['amount'], 2); ?></td>
                                    <td><?php echo isset($payment_methods[$payment['payment_method']]) ? $payment_methods[$payment['payment_method']] : '未知'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($payment['payment_time'])); ?></td>
                                    <td>
                                        <?php
                                        $status_text = '';
                                        $status_class = '';
                                        switch ($payment['status']) {
                                            case 1:
                                                $status_text = '已支付';
                                                $status_class = 'status-active';
                                                break;
                                            case 2:
                                                $status_text = '已退款';
                                                $status_class = 'status-warning';
                                                break;
                                            case 3:
                                                $status_text = '已取消';
                                                $status_class = 'status-inactive';
                                                break;
                                        }
                                        ?>
                                        <span class="<?php echo $status_class; ?>"><?php echo $status_text; ?></span>
                                    </td>
                                    <td>
                                        <a href="bill.php?view=<?php echo $payment['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        <?php if ($payment['status'] != 3): ?>
                                            <a href="bill.php?edit=<?php echo $payment['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                            <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要取消此账单吗？');">
                                                <input type="hidden" name="action" value="cancel">
                                                <input type="hidden" name="payment_id" value="<?php echo $payment['id']; ?>">
                                                <input type="hidden" name="cancel_reason" value="手动取消">
                                                <button type="submit" class="btn btn-sm btn-warning">取消</button>
                                            </form>
                                        <?php endif; ?>

                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此账单吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="payment_id" value="<?php echo $payment['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    </td>
                                </tr>
                                <?php if ($view_payment_id == $payment['id']): ?>
                                    <tr>
                                        <td colspan="9" class="details-row">
                                            <div class="payment-details">
                                                <div class="detail-group">
                                                    <h4>基本信息</h4>
                                                    <p><strong>支付单号：</strong> <?php echo $payment['payment_no']; ?></p>
                                                    <p><strong>类型：</strong> <?php echo $payment['type'] == 1 ? '收款' : '退款'; ?></p>
                                                    <p><strong>金额：</strong> ￥<?php echo number_format($payment['amount'], 2); ?></p>
                                                    <p><strong>支付方式：</strong> <?php echo isset($payment_methods[$payment['payment_method']]) ? $payment_methods[$payment['payment_method']] : '未知'; ?></p>
                                                    <p><strong>支付时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($payment['payment_time'])); ?></p>
                                                    <p><strong>状态：</strong>
                                                        <?php
                                                        switch ($payment['status']) {
                                                            case 1:
                                                                echo '已支付';
                                                                break;
                                                            case 2:
                                                                echo '已退款';
                                                                break;
                                                            case 3:
                                                                echo '已取消';
                                                                break;
                                                        }
                                                        ?>
                                                    </p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>关联信息</h4>
                                                    <?php if ($payment['booking_id']): ?>
                                                        <p><strong>预订单号：</strong> <?php echo $payment['order_no']; ?></p>
                                                    <?php endif; ?>
                                                    <?php if ($payment['checkin_id']): ?>
                                                        <p><strong>入住单号：</strong> <?php echo $payment['order_no']; ?></p>
                                                    <?php endif; ?>
                                                    <p><strong>客人姓名：</strong> <?php echo $payment['guest_name'] ?: '-'; ?></p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>其他信息</h4>
                                                    <p><strong>操作人员：</strong> <?php echo $payment['operator_name'] ?: '-'; ?></p>
                                                    <p><strong>备注：</strong> <?php echo $payment['remark'] ?: '-'; ?></p>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                            <?php if (count($payments) == 0): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无账单记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // 预订单和入住单互斥选择
            const bookingSelect = document.getElementById('booking_id');
            const checkinSelect = document.getElementById('checkin_id');

            if (bookingSelect && checkinSelect) {
                bookingSelect.addEventListener('change', function() {
                    if (this.value != '0') {
                        checkinSelect.value = '0';
                    }
                });

                checkinSelect.addEventListener('change', function() {
                    if (this.value != '0') {
                        bookingSelect.value = '0';
                    }
                });
            }
        });
    </script>
</body>

</html>