<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问客房管理首页');

// 获取房间总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as total FROM room_info");
    $room_count = $stmt->fetch()['total'];
} catch (PDOException $e) {
    $room_count = 0;
}

// 获取不同状态的房间数量
try {
    $stmt = $pdo->query("
        SELECT status, COUNT(*) as count 
        FROM room_info 
        GROUP BY status
    ");
    $status_counts = [];
    while ($row = $stmt->fetch()) {
        $status_counts[$row['status']] = $row['count'];
    }
} catch (PDOException $e) {
    $status_counts = [];
}

// 获取各房型数量
try {
    $stmt = $pdo->query("
        SELECT t.type_name, COUNT(r.id) as count 
        FROM room_info r
        JOIN room_types t ON r.room_type_id = t.id
        GROUP BY r.room_type_id
    ");
    $type_counts = [];
    while ($row = $stmt->fetch()) {
        $type_counts[$row['type_name']] = $row['count'];
    }
} catch (PDOException $e) {
    $type_counts = [];
}

// 获取待处理的维修任务数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as total FROM room_maintenance WHERE status = 1");
    $pending_maintenance = $stmt->fetch()['total'];
} catch (PDOException $e) {
    $pending_maintenance = 0;
}

// 获取今日清洁任务数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as total FROM room_cleaning WHERE clean_date = CURDATE()");
    $today_cleaning = $stmt->fetch()['total'];
} catch (PDOException $e) {
    $today_cleaning = 0;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>客房管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客房管理</h2>
        </div>

        <div class="content">
            <!-- 房间状态统计 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总房间数</h3>
                    <div class="number"><?php echo $room_count; ?></div>
                    <div class="desc">所有房间总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>空闲房间</h3>
                    <div class="number"><?php echo isset($status_counts[1]) ? $status_counts[1] : 0; ?></div>
                    <div class="desc">当前可预订房间</div>
                </div>

                <div class="dashboard-card">
                    <h3>已预订</h3>
                    <div class="number"><?php echo isset($status_counts[2]) ? $status_counts[2] : 0; ?></div>
                    <div class="desc">已被预订的房间</div>
                </div>

                <div class="dashboard-card">
                    <h3>已入住</h3>
                    <div class="number"><?php echo isset($status_counts[3]) ? $status_counts[3] : 0; ?></div>
                    <div class="desc">当前入住中的房间</div>
                </div>

                <div class="dashboard-card">
                    <h3>清洁维修</h3>
                    <div class="number"><?php echo (isset($status_counts[4]) ? $status_counts[4] : 0) + (isset($status_counts[5]) ? $status_counts[5] : 0); ?></div>
                    <div class="desc">清洁或维修中房间</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="status.php" class="function-link">
                    <h3>房态管理</h3>                    
                </a>

                <a href="type.php" class="function-link">
                    <h3>房型管理</h3>
                </a>

                <a href="items.php" class="function-link">
                    <h3>物品管理</h3>
                </a>

                <a href="cleaning.php" class="function-link">
                    <h3>清洁管理</h3>
                </a>

                <a href="maintenance.php" class="function-link">
                    <h3>维修管理</h3>
                </a>
            </div>

            <!-- 房型统计 -->
            <div class="system-info">
                <h3>房型分布</h3>
                <table class="info-table">
                    <?php foreach ($type_counts as $type_name => $count): ?>
                        <tr>
                            <td width="70%"><?php echo $type_name; ?></td>
                            <td width="30%"><?php echo $count; ?> 间</td>
                        </tr>
                    <?php endforeach; ?>
                </table>
            </div>
        </div>
    </div>
</body>

</html>