<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问物品管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加物品
    if ($_POST['action'] == 'add') {
        $item_name = isset($_POST['item_name']) ? trim($_POST['item_name']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '个';
        $is_consumable = isset($_POST['is_consumable']) ? intval($_POST['is_consumable']) : 1;
        $standard_quantity = isset($_POST['standard_quantity']) ? intval($_POST['standard_quantity']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($item_name) || empty($category)) {
            $error = '物品名称和分类必须填写！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    INSERT INTO room_items (
                        item_name, category, unit, is_consumable, standard_quantity, status
                    ) VALUES (?, ?, ?, ?, ?, ?)
                ");
                $result = $stmt->execute([
                    $item_name,
                    $category,
                    $unit,
                    $is_consumable,
                    $standard_quantity,
                    $status
                ]);

                if ($result) {
                    record_log("添加房间物品：{$item_name}");
                    $success = '物品添加成功！';
                } else {
                    $error = '物品添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑物品
    elseif ($_POST['action'] == 'edit') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;
        $item_name = isset($_POST['item_name']) ? trim($_POST['item_name']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '个';
        $is_consumable = isset($_POST['is_consumable']) ? intval($_POST['is_consumable']) : 1;
        $standard_quantity = isset($_POST['standard_quantity']) ? intval($_POST['standard_quantity']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($item_id <= 0 || empty($item_name) || empty($category)) {
            $error = '物品ID、名称和分类必须填写！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE room_items 
                    SET item_name = ?, category = ?, unit = ?, is_consumable = ?, 
                        standard_quantity = ?, status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([
                    $item_name,
                    $category,
                    $unit,
                    $is_consumable,
                    $standard_quantity,
                    $status,
                    $item_id
                ]);

                if ($result) {
                    record_log("编辑房间物品：{$item_name}，ID：{$item_id}");
                    $success = '物品更新成功！';
                } else {
                    $error = '物品更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除物品
    elseif ($_POST['action'] == 'delete') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;

        if ($item_id <= 0) {
            $error = '无效的物品ID！';
        } else {
            try {
                // 获取物品名称，用于日志记录
                $stmt = $pdo->prepare("SELECT item_name FROM room_items WHERE id = ?");
                $stmt->execute([$item_id]);
                $item = $stmt->fetch();

                if (!$item) {
                    $error = '物品不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM room_items WHERE id = ?");
                    $result = $stmt->execute([$item_id]);

                    if ($result) {
                        record_log("删除房间物品：{$item['item_name']}，ID：{$item_id}");
                        $success = '物品删除成功！';
                    } else {
                        $error = '物品删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 切换物品状态
    elseif ($_POST['action'] == 'toggle_status') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;
        $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;

        if ($item_id <= 0) {
            $error = '无效的物品ID！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE room_items 
                    SET status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$new_status, $item_id]);

                if ($result) {
                    $status_text = $new_status == 1 ? '启用' : '禁用';
                    record_log("切换房间物品状态为{$status_text}，ID：{$item_id}");
                    $success = "物品{$status_text}成功！";
                } else {
                    $error = '状态切换失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取物品详情
$edit_item = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $item_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM room_items WHERE id = ?");
        $stmt->execute([$item_id]);
        $edit_item = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取物品详情失败：' . $e->getMessage();
    }
}

// 获取所有分类
try {
    $stmt = $pdo->query("SELECT DISTINCT category FROM room_items ORDER BY category");
    $categories = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $categories = [];
}

// 获取所有物品
$filter_category = isset($_GET['category']) ? trim($_GET['category']) : '';
$filter_consumable = isset($_GET['consumable']) ? intval($_GET['consumable']) : -1;

try {
    $sql = "SELECT * FROM room_items WHERE 1=1";
    $params = [];

    if (!empty($filter_category)) {
        $sql .= " AND category = ?";
        $params[] = $filter_category;
    }

    if ($filter_consumable >= 0) {
        $sql .= " AND is_consumable = ?";
        $params[] = $filter_consumable;
    }

    $sql .= " ORDER BY category, item_name";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $items = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取物品列表失败：' . $e->getMessage();
    $items = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>物品管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>物品管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客房管理</a> &gt; 物品管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$edit_item && !$show_add_form): ?>
                    <a href="items.php?show_form=add" class="btn btn-primary">添加物品</a>
                <?php endif; ?>
            </div>

            <?php if ($edit_item): ?>
                <!-- 编辑物品表单 -->
                <h3>编辑物品</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="item_id" value="<?php echo $edit_item['id']; ?>">

                        <div class="form-group">
                            <label for="item_name">物品名称：</label>
                            <input type="text" id="item_name" name="item_name" value="<?php echo $edit_item['item_name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="category">分类：</label>
                            <input type="text" id="category" name="category" value="<?php echo $edit_item['category']; ?>" list="category_list" required>
                            <datalist id="category_list">
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category; ?>">
                                    <?php endforeach; ?>
                            </datalist>
                        </div>

                        <div class="form-group">
                            <label for="unit">单位：</label>
                            <input type="text" id="unit" name="unit" value="<?php echo $edit_item['unit']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="is_consumable">是否消耗品：</label>
                            <select id="is_consumable" name="is_consumable">
                                <option value="1" <?php echo $edit_item['is_consumable'] == 1 ? 'selected' : ''; ?>>是</option>
                                <option value="0" <?php echo $edit_item['is_consumable'] == 0 ? 'selected' : ''; ?>>否</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="standard_quantity">标准数量：</label>
                            <input type="number" id="standard_quantity" name="standard_quantity" min="1" value="<?php echo $edit_item['standard_quantity']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_item['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_item['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="items.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_add_form): ?>
                <!-- 添加物品表单 -->
                <h3>添加物品</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="item_name">物品名称：</label>
                            <input type="text" id="item_name" name="item_name" required>
                        </div>

                        <div class="form-group">
                            <label for="category">分类：</label>
                            <input type="text" id="category" name="category" list="category_list" required>
                            <datalist id="category_list">
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category; ?>">
                                    <?php endforeach; ?>
                            </datalist>
                        </div>

                        <div class="form-group">
                            <label for="unit">单位：</label>
                            <input type="text" id="unit" name="unit" value="个">
                        </div>

                        <div class="form-group">
                            <label for="is_consumable">是否消耗品：</label>
                            <select id="is_consumable" name="is_consumable">
                                <option value="1" selected>是</option>
                                <option value="0">否</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="standard_quantity">标准数量：</label>
                            <input type="number" id="standard_quantity" name="standard_quantity" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" selected>启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="items.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="category">分类：</label>
                            <select id="category" name="category">
                                <option value="">全部分类</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category; ?>" <?php echo $filter_category == $category ? 'selected' : ''; ?>>
                                        <?php echo $category; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="consumable">物品类型：</label>
                            <select id="consumable" name="consumable">
                                <option value="-1">全部</option>
                                <option value="1" <?php echo $filter_consumable == 1 ? 'selected' : ''; ?>>消耗品</option>
                                <option value="0" <?php echo $filter_consumable == 0 ? 'selected' : ''; ?>>非消耗品</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="items.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <h3>物品列表</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>物品名称</th>
                            <th>分类</th>
                            <th>单位</th>
                            <th>物品类型</th>
                            <th>标准数量</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($items as $item): ?>
                            <tr>
                                <td><?php echo $item['id']; ?></td>
                                <td><?php echo $item['item_name']; ?></td>
                                <td><?php echo $item['category']; ?></td>
                                <td><?php echo $item['unit']; ?></td>
                                <td><?php echo $item['is_consumable'] == 1 ? '消耗品' : '非消耗品'; ?></td>
                                <td><?php echo $item['standard_quantity']; ?></td>
                                <td>
                                    <?php if ($item['status'] == 1): ?>
                                        <span class="status-active">启用</span>
                                    <?php else: ?>
                                        <span class="status-inactive">禁用</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="items.php?edit=<?php echo $item['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                    <form method="post" action="" style="display:inline;">
                                        <input type="hidden" name="action" value="toggle_status">
                                        <input type="hidden" name="item_id" value="<?php echo $item['id']; ?>">
                                        <input type="hidden" name="status" value="<?php echo $item['status'] == 1 ? 0 : 1; ?>">
                                        <button type="submit" class="btn btn-sm <?php echo $item['status'] == 1 ? 'btn-warning' : 'btn-success'; ?>">
                                            <?php echo $item['status'] == 1 ? '禁用' : '启用'; ?>
                                        </button>
                                    </form>

                                    <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此物品吗？此操作不可恢复！');">
                                        <input type="hidden" name="action" value="delete">
                                        <input type="hidden" name="item_id" value="<?php echo $item['id']; ?>">
                                        <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>