<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问房型管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加房型
    if ($_POST['action'] == 'add') {
        $type_name = isset($_POST['type_name']) ? trim($_POST['type_name']) : '';
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $capacity = isset($_POST['capacity']) ? intval($_POST['capacity']) : 2;
        $bed_count = isset($_POST['bed_count']) ? intval($_POST['bed_count']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($type_name) || $price <= 0) {
            $error = '房型名称和价格必须填写！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    INSERT INTO room_types (
                        type_name, price, capacity, bed_count, description, status
                    ) VALUES (?, ?, ?, ?, ?, ?)
                ");
                $result = $stmt->execute([
                    $type_name,
                    $price,
                    $capacity,
                    $bed_count,
                    $description,
                    $status
                ]);

                if ($result) {
                    record_log("添加房型：{$type_name}");
                    $success = '房型添加成功！';
                } else {
                    $error = '房型添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑房型
    elseif ($_POST['action'] == 'edit') {
        $type_id = isset($_POST['type_id']) ? intval($_POST['type_id']) : 0;
        $type_name = isset($_POST['type_name']) ? trim($_POST['type_name']) : '';
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $capacity = isset($_POST['capacity']) ? intval($_POST['capacity']) : 2;
        $bed_count = isset($_POST['bed_count']) ? intval($_POST['bed_count']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($type_id <= 0 || empty($type_name) || $price <= 0) {
            $error = '房型ID、名称和价格必须填写！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE room_types 
                    SET type_name = ?, price = ?, capacity = ?, bed_count = ?, 
                        description = ?, status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([
                    $type_name,
                    $price,
                    $capacity,
                    $bed_count,
                    $description,
                    $status,
                    $type_id
                ]);

                if ($result) {
                    record_log("编辑房型：{$type_name}，ID：{$type_id}");
                    $success = '房型更新成功！';
                } else {
                    $error = '房型更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除房型
    elseif ($_POST['action'] == 'delete') {
        $type_id = isset($_POST['type_id']) ? intval($_POST['type_id']) : 0;

        if ($type_id <= 0) {
            $error = '无效的房型ID！';
        } else {
            try {
                // 检查是否有房间使用此房型
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM room_info WHERE room_type_id = ?");
                $stmt->execute([$type_id]);
                $count = $stmt->fetch()['count'];

                if ($count > 0) {
                    $error = '该房型下存在房间，不能删除！';
                } else {
                    // 获取房型名称，用于日志记录
                    $stmt = $pdo->prepare("SELECT type_name FROM room_types WHERE id = ?");
                    $stmt->execute([$type_id]);
                    $type = $stmt->fetch();

                    if (!$type) {
                        $error = '房型不存在！';
                    } else {
                        $stmt = $pdo->prepare("DELETE FROM room_types WHERE id = ?");
                        $result = $stmt->execute([$type_id]);

                        if ($result) {
                            record_log("删除房型：{$type['type_name']}，ID：{$type_id}");
                            $success = '房型删除成功！';
                        } else {
                            $error = '房型删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 切换房型状态
    elseif ($_POST['action'] == 'toggle_status') {
        $type_id = isset($_POST['type_id']) ? intval($_POST['type_id']) : 0;
        $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;

        if ($type_id <= 0) {
            $error = '无效的房型ID！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE room_types 
                    SET status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$new_status, $type_id]);

                if ($result) {
                    $status_text = $new_status == 1 ? '启用' : '禁用';
                    record_log("切换房型状态为{$status_text}，ID：{$type_id}");
                    $success = "房型{$status_text}成功！";
                } else {
                    $error = '状态切换失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取房型详情
$edit_type = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $type_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM room_types WHERE id = ?");
        $stmt->execute([$type_id]);
        $edit_type = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取房型详情失败：' . $e->getMessage();
    }
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT * FROM room_types ORDER BY id");
    $types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $types = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>房型管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>房型管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客房管理</a> &gt; 房型管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$edit_type && !$show_add_form): ?>
                    <a href="type.php?show_form=add" class="btn btn-primary">添加房型</a>
                <?php endif; ?>
            </div>

            <?php if ($edit_type): ?>
                <!-- 编辑房型表单 -->
                <h3>编辑房型</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="type_id" value="<?php echo $edit_type['id']; ?>">

                        <div class="form-group">
                            <label for="type_name">房型名称：</label>
                            <input type="text" id="type_name" name="type_name" value="<?php echo $edit_type['type_name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="price">标准价格：</label>
                            <input type="number" id="price" name="price" step="0.01" min="0" value="<?php echo $edit_type['price']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="capacity">最大容纳人数：</label>
                            <input type="number" id="capacity" name="capacity" min="1" value="<?php echo $edit_type['capacity']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="bed_count">床位数：</label>
                            <input type="number" id="bed_count" name="bed_count" min="1" value="<?php echo $edit_type['bed_count']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="description">房型描述：</label>
                            <textarea id="description" name="description" rows="3"><?php echo $edit_type['description']; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_type['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_type['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="type.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_add_form): ?>
                <!-- 添加房型表单 -->
                <h3>添加房型</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="type_name">房型名称：</label>
                            <input type="text" id="type_name" name="type_name" required>
                        </div>

                        <div class="form-group">
                            <label for="price">标准价格：</label>
                            <input type="number" id="price" name="price" step="0.01" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="capacity">最大容纳人数：</label>
                            <input type="number" id="capacity" name="capacity" min="1" value="2" required>
                        </div>

                        <div class="form-group">
                            <label for="bed_count">床位数：</label>
                            <input type="number" id="bed_count" name="bed_count" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="description">房型描述：</label>
                            <textarea id="description" name="description" rows="3"></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" selected>启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="type.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <h3>房型列表</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>房型名称</th>
                            <th>价格</th>
                            <th>容纳人数</th>
                            <th>床位数</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($types as $type): ?>
                            <tr>
                                <td><?php echo $type['id']; ?></td>
                                <td><?php echo $type['type_name']; ?></td>
                                <td>￥<?php echo number_format($type['price'], 2); ?></td>
                                <td><?php echo $type['capacity']; ?> 人</td>
                                <td><?php echo $type['bed_count']; ?> 张</td>
                                <td>
                                    <?php if ($type['status'] == 1): ?>
                                        <span class="status-active">启用</span>
                                    <?php else: ?>
                                        <span class="status-inactive">禁用</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="type.php?edit=<?php echo $type['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                    <form method="post" action="" style="display:inline;">
                                        <input type="hidden" name="action" value="toggle_status">
                                        <input type="hidden" name="type_id" value="<?php echo $type['id']; ?>">
                                        <input type="hidden" name="status" value="<?php echo $type['status'] == 1 ? 0 : 1; ?>">
                                        <button type="submit" class="btn btn-sm <?php echo $type['status'] == 1 ? 'btn-warning' : 'btn-success'; ?>">
                                            <?php echo $type['status'] == 1 ? '禁用' : '启用'; ?>
                                        </button>
                                    </form>

                                    <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此房型吗？此操作不可恢复！');">
                                        <input type="hidden" name="action" value="delete">
                                        <input type="hidden" name="type_id" value="<?php echo $type['id']; ?>">
                                        <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>