-- 1、用户与权限管理
-- 用户表
CREATE TABLE `sys_users` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
    `username` varchar(50) NOT NULL COMMENT '用户名',
    `password` varchar(255) NOT NULL COMMENT '密码',
    `mobile` varchar(20) DEFAULT NULL COMMENT '手机号',
    `role_id` int(11) NOT NULL DEFAULT 2 COMMENT '角色ID',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=启用，0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_username` (`username`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '系统用户表';

-- 角色权限表
CREATE TABLE `sys_roles` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
    `role_name` varchar(50) NOT NULL COMMENT '角色名称',
    `permissions` text DEFAULT NULL COMMENT '权限(JSON格式)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '角色权限表';

-- 操作日志表
CREATE TABLE `sys_logs` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '日志ID',
    `user_id` int(11) DEFAULT NULL COMMENT '操作用户ID',
    `username` varchar(50) DEFAULT NULL COMMENT '操作用户名',
    `operation` varchar(500) NOT NULL COMMENT '操作描述',
    `ip` varchar(50) DEFAULT NULL COMMENT '操作IP',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '操作日志表';

-- 数据备份表
CREATE TABLE `sys_backups` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '备份ID',
    `backup_name` varchar(100) NOT NULL COMMENT '备份名称',
    `backup_path` varchar(255) NOT NULL COMMENT '备份文件路径',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '数据备份表';

-- 初始化角色数据
INSERT INTO
    `sys_roles` (`id`, `role_name`, `permissions`)
VALUES
    (
        1,
        '系统管理员',
        '{"all": true, "system": true, "user": true, "role": true, "backup": true, "language": true}'
    ),
    (
        2,
        '前台接待',
        '{"booking": true, "checkin": true, "checkout": true, "guest": true}'
    ),
    (
        3,
        '客房服务',
        '{"room": true, "housekeeping": true, "maintenance": true}'
    ),
    (
        4,
        '财务',
        '{"finance": true, "billing": true, "report": true}'
    ),
    (
        5,
        '客户',
        '{"booking": {"view": true, "create": true}, "profile": true}'
    );

-- 语言设置表
CREATE TABLE `languages` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `code` varchar(10) NOT NULL COMMENT '语言代码',
    `name` varchar(50) NOT NULL COMMENT '语言名称',
    `is_default` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否默认语言',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=启用，0=禁用',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_code` (`code`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '语言设置表';

-- 初始语言数据
INSERT INTO
    `languages` (`code`, `name`, `is_default`, `status`)
VALUES
    ('zh-CN', '简体中文', 1, 1),
    ('en-US', 'English', 0, 1),
    ('ja-JP', '日本語', 0, 1);

-- 密码为admin的MD5哈希值，实际应用中建议使用更安全的加密方式
INSERT INTO
    `sys_users` (
        `username`,
        `password`,
        `mobile`,
        `role_id`,
        `status`
    )
VALUES
    (
        'admin',
        '21232f297a57a5a743894a0e4a801fc3',
        '13800138000',
        1,
        1
    );

-- 注意：权限管理相关表结构已全部更新完成
-- 此次改动的优势：
-- 1. 使用JSON格式存储权限，更加灵活，可以支持层级权限设计
-- 2. 简化了数据库结构，减少了表的数量，降低了查询复杂度
-- 3. 添加或修改权限时无需修改数据库结构，只需更新JSON数据即可
-- 4. 角色和权限一体化管理，提高了系统维护效率
-- 5. 统一了表前缀(sys_)，使系统表命名更规范
-- ==================================
-- 2、客户管理模块
-- ==================================
-- 会员等级表
CREATE TABLE `guest_member_levels` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '等级ID',
    `level_name` varchar(30) NOT NULL COMMENT '等级名称',
    `min_points` int(11) NOT NULL DEFAULT 0 COMMENT '所需最低积分',
    `discount_rate` decimal(4, 2) NOT NULL DEFAULT 1.00 COMMENT '折扣率',
    `description` varchar(255) DEFAULT NULL COMMENT '等级描述',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员等级表';

-- 客户会员表（会员系统+客户档案+客户偏好合并）
CREATE TABLE `guest_members` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '会员ID',
    `member_no` varchar(20) NOT NULL COMMENT '会员编号',
    `name` varchar(50) NOT NULL COMMENT '姓名',
    `gender` tinyint(1) DEFAULT 0 COMMENT '性别(0:未知,1:男,2:女)',
    `mobile` varchar(20) NOT NULL COMMENT '手机号',
    `email` varchar(100) DEFAULT NULL COMMENT '邮箱',
    `id_type` tinyint(1) DEFAULT 1 COMMENT '证件类型(1:身份证,2:护照)',
    `id_number` varchar(30) DEFAULT NULL COMMENT '证件号码',
    `birthday` date DEFAULT NULL COMMENT '生日',
    `level_id` int(11) NOT NULL DEFAULT 1 COMMENT '会员等级ID',
    `points` int(11) NOT NULL DEFAULT 0 COMMENT '积分',
    `total_amount` decimal(10, 2) NOT NULL DEFAULT 0 COMMENT '累计消费',
    `stay_count` int(11) NOT NULL DEFAULT 0 COMMENT '入住次数',
    -- 客户偏好字段
    `room_type` varchar(50) DEFAULT NULL COMMENT '偏好房型',
    `is_smoking` tinyint(1) DEFAULT 0 COMMENT '是否吸烟(0:否,1:是)',
    `bed_preference` varchar(50) DEFAULT NULL COMMENT '床型偏好',
    `floor_preference` varchar(50) DEFAULT NULL COMMENT '楼层偏好',
    `other_requests` varchar(500) DEFAULT NULL COMMENT '其他特殊需求',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '注册时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_member_no` (`member_no`),
    UNIQUE KEY `idx_mobile` (`mobile`),
    KEY `idx_level_id` (`level_id`),
    CONSTRAINT `fk_member_level` FOREIGN KEY (`level_id`) REFERENCES `guest_member_levels` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '客户会员表';

-- 客户投诉表
CREATE TABLE `guest_complaints` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '投诉ID',
    `complaint_no` varchar(20) NOT NULL COMMENT '投诉编号',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID',
    `guest_name` varchar(50) NOT NULL COMMENT '客人姓名',
    `contact` varchar(50) NOT NULL COMMENT '联系方式',
    `booking_no` varchar(20) DEFAULT NULL COMMENT '关联预订号',
    `complaint_type` tinyint(1) NOT NULL COMMENT '投诉类型(1:客房设施,2:服务态度,3:噪音干扰,4:卫生问题,5:餐饮相关,6:其他)',
    `complaint_content` text NOT NULL COMMENT '投诉内容',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:待处理,2:处理中,3:已解决,4:未解决)',
    `handle_content` text DEFAULT NULL COMMENT '处理内容',
    `handler_id` int(11) DEFAULT NULL COMMENT '处理人ID',
    `handle_time` datetime DEFAULT NULL COMMENT '处理时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_complaint_no` (`complaint_no`),
    KEY `idx_member_id` (`member_id`),
    KEY `idx_status` (`status`),
    CONSTRAINT `fk_complaint_member` FOREIGN KEY (`member_id`) REFERENCES `guest_members` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '客户投诉表';

-- 营销活动表
CREATE TABLE `guest_marketing_campaigns` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '活动ID',
    `campaign_name` varchar(100) NOT NULL COMMENT '活动名称',
    `campaign_type` tinyint(1) NOT NULL COMMENT '活动类型(1:短信营销,2:邮件营销,3:优惠券)',
    `content` text NOT NULL COMMENT '活动内容',
    `target_level_id` int(11) DEFAULT NULL COMMENT '目标等级ID(NULL表示所有等级)',
    `start_time` datetime NOT NULL COMMENT '开始时间',
    `end_time` datetime NOT NULL COMMENT '结束时间',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_target_level` (`target_level_id`),
    KEY `idx_time` (`start_time`, `end_time`),
    CONSTRAINT `fk_campaign_level` FOREIGN KEY (`target_level_id`) REFERENCES `guest_member_levels` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销活动表';

-- 客户管理相关功能说明:
-- 1. 客户会员表整合了会员基本信息、客户档案和客户偏好信息
-- 2. 积分变动和其他客户相关操作通过sys_logs系统日志表记录
-- 3. 删除了单独的客户偏好表和积分日志表，简化了数据结构
-- 初始化客户管理模块数据
-- 会员等级数据
INSERT INTO
    `guest_member_levels` (
        `level_name`,
        `min_points`,
        `discount_rate`,
        `description`
    )
VALUES
    ('普通会员', 0, 1.00, '基础会员权益'),
    ('银卡会员', 1000, 0.95, '95折房费优惠'),
    ('金卡会员', 5000, 0.90, '9折房费优惠'),
    ('钻石会员', 10000, 0.85, '85折房费优惠、欢迎水果、生日礼遇');

-- 会员示例数据（已包含客户偏好）
INSERT INTO
    `guest_members` (
        `member_no`,
        `name`,
        `gender`,
        `mobile`,
        `email`,
        `id_type`,
        `id_number`,
        `birthday`,
        `level_id`,
        `points`,
        `total_amount`,
        `stay_count`,
        `room_type`,
        `is_smoking`,
        `bed_preference`,
        `floor_preference`,
        `other_requests`
    )
VALUES
    (
        'M202301001',
        '张三',
        1,
        '13800138001',
        'zhangsan@example.com',
        1,
        '110101199001011234',
        '1990-01-01',
        2,
        1200,
        2580.00,
        3,
        '大床房',
        0,
        '特软',
        '高楼层',
        '希望有窗户，安静的房间'
    ),
    (
        'M202301002',
        '李四',
        1,
        '13800138002',
        'lisi@example.com',
        1,
        '110101199203034321',
        '1992-03-03',
        3,
        6500,
        12800.00,
        8,
        '豪华套房',
        0,
        '特硬',
        '顶层',
        '希望有浴缸'
    ),
    (
        'M202301003',
        '王五',
        2,
        '13800138003',
        'wangwu@example.com',
        1,
        '110101199505055678',
        '1995-05-05',
        1,
        580,
        1200.00,
        1,
        '标准间',
        0,
        '普通',
        '低楼层',
        '无特殊要求'
    );

-- 客户投诉示例
INSERT INTO
    `guest_complaints` (
        `complaint_no`,
        `member_id`,
        `guest_name`,
        `contact`,
        `booking_no`,
        `complaint_type`,
        `complaint_content`,
        `status`,
        `handle_content`,
        `handler_id`,
        `handle_time`
    )
VALUES
    (
        'CP20230501001',
        1,
        '张三',
        '13800138001',
        'BK20230320003',
        2,
        '前台服务态度冷漠，办理入住时等待时间过长',
        3,
        '已电话致歉，并对相关人员进行培训',
        1,
        '2023-05-03 14:30:00'
    ),
    (
        'CP20230510001',
        2,
        '李四',
        '13800138002',
        'BK20230420004',
        1,
        '房间空调不制冷，影响睡眠质量',
        2,
        '已安排维修人员检修',
        2,
        '2023-05-10 10:15:00'
    );

-- 营销活动示例
INSERT INTO
    `guest_marketing_campaigns` (
        `campaign_name`,
        `campaign_type`,
        `content`,
        `target_level_id`,
        `start_time`,
        `end_time`,
        `status`
    )
VALUES
    (
        '五一假期特惠',
        1,
        '尊敬的会员，五一期间入住享9折优惠，提前预订更有惊喜！',
        NULL,
        '2023-04-20 00:00:00',
        '2023-05-05 23:59:59',
        1
    ),
    (
        '钻石会员专享',
        2,
        '尊敬的钻石会员，感谢您一直以来的支持，本月入住可获得双倍积分奖励！',
        4,
        '2023-05-01 00:00:00',
        '2023-05-31 23:59:59',
        1
    ),
    (
        '生日特惠券',
        3,
        '生日当月入住，赠送价值100元的餐饮代金券一张',
        NULL,
        '2023-01-01 00:00:00',
        '2023-12-31 23:59:59',
        1
    );

-- ==================================
-- 3、客房管理模块
-- ==================================
-- 房型表
CREATE TABLE `room_types` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '房型ID',
    `type_name` varchar(50) NOT NULL COMMENT '房型名称',
    `price` decimal(10, 2) NOT NULL COMMENT '标准价格',
    `capacity` int(11) NOT NULL DEFAULT 2 COMMENT '最大容纳人数',
    `bed_count` int(11) NOT NULL DEFAULT 1 COMMENT '床位数',
    `description` text DEFAULT NULL COMMENT '房型描述',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '房型表';

-- 房间信息表
CREATE TABLE `room_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '房间ID',
    `room_number` varchar(20) NOT NULL COMMENT '房间号',
    `room_type_id` int(11) NOT NULL COMMENT '房型ID',
    `floor` varchar(10) NOT NULL COMMENT '楼层',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '房态(1:空闲,2:已预订,3:已入住,4:清洁中,5:维修中,6:停用)',
    `is_smoking` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否吸烟房(0:否,1:是)',
    `remarks` varchar(255) DEFAULT NULL COMMENT '备注',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_room_number` (`room_number`),
    KEY `idx_room_type_id` (`room_type_id`),
    KEY `idx_status` (`status`),
    CONSTRAINT `fk_room_type` FOREIGN KEY (`room_type_id`) REFERENCES `room_types` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '房间信息表';

-- 房间物品表
CREATE TABLE `room_items` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '物品ID',
    `item_name` varchar(50) NOT NULL COMMENT '物品名称',
    `category` varchar(50) NOT NULL COMMENT '物品分类',
    `unit` varchar(20) NOT NULL DEFAULT '个' COMMENT '单位',
    `is_consumable` tinyint(1) NOT NULL DEFAULT 1 COMMENT '是否消耗品(0:否,1:是)',
    `standard_quantity` int(11) NOT NULL DEFAULT 1 COMMENT '标准配置数量',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '房间物品表';

-- 房间清洁表
CREATE TABLE `room_cleaning` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '清洁ID',
    `room_id` int(11) NOT NULL COMMENT '房间ID',
    `clean_date` date NOT NULL COMMENT '清洁日期',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:待处理,2:处理中,3:已完成)',
    `cleaner_id` int(11) DEFAULT NULL COMMENT '清洁员ID',
    `remarks` varchar(255) DEFAULT NULL COMMENT '备注',
    `complete_time` datetime DEFAULT NULL COMMENT '完成时间',
    PRIMARY KEY (`id`),
    KEY `idx_room_id` (`room_id`),
    KEY `idx_clean_date` (`clean_date`),
    CONSTRAINT `fk_cleaning_room` FOREIGN KEY (`room_id`) REFERENCES `room_info` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '房间清洁表';

-- 房间维修表
CREATE TABLE `room_maintenance` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '维修ID',
    `room_id` int(11) NOT NULL COMMENT '房间ID',
    `issue_type` varchar(50) NOT NULL COMMENT '问题类型',
    `issue_desc` varchar(500) NOT NULL COMMENT '问题描述',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:待处理,2:处理中,3:已完成)',
    `reporter_id` int(11) DEFAULT NULL COMMENT '报修人ID',
    `maintainer_id` int(11) DEFAULT NULL COMMENT '维修员ID',
    `report_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '报修时间',
    `complete_time` datetime DEFAULT NULL COMMENT '完成时间',
    PRIMARY KEY (`id`),
    KEY `idx_room_id` (`room_id`),
    CONSTRAINT `fk_maintenance_room` FOREIGN KEY (`room_id`) REFERENCES `room_info` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '房间维修表';

-- 初始化客房管理模块数据
-- 初始化房型数据
INSERT INTO
    `room_types` (
        `type_name`,
        `price`,
        `capacity`,
        `bed_count`,
        `description`,
        `status`
    )
VALUES
    ('标准单人间', 288.00, 1, 1, '标准单人间，配备1张单人床', 1),
    ('标准双人间', 368.00, 2, 2, '标准双人间，配备2张单人床', 1),
    ('豪华大床房', 488.00, 2, 1, '豪华大床房，配备1张特大床', 1),
    ('商务套房', 688.00, 2, 1, '商务套房，设有独立客厅和卧室', 1);

-- 初始化房间数据
INSERT INTO
    `room_info` (
        `room_number`,
        `room_type_id`,
        `floor`,
        `status`,
        `is_smoking`,
        `remarks`
    )
VALUES
    ('101', 1, '1', 1, 0, '靠近电梯'),
    ('102', 2, '1', 1, 0, '靠近楼梯'),
    ('201', 3, '2', 3, 0, '有窗景观好'),
    ('202', 3, '2', 4, 0, '角房间，视野开阔');

-- 初始化物品数据
INSERT INTO
    `room_items` (
        `item_name`,
        `category`,
        `unit`,
        `is_consumable`,
        `standard_quantity`,
        `status`
    )
VALUES
    ('床单', '床上用品', '套', 0, 1, 1),
    ('毛巾', '洗浴用品', '条', 1, 2, 1),
    ('浴巾', '洗浴用品', '条', 1, 2, 1),
    ('洗发水', '洗浴用品', '瓶', 1, 1, 1),
    ('沐浴露', '洗浴用品', '瓶', 1, 1, 1);

-- 初始化清洁任务数据
INSERT INTO
    `room_cleaning` (
        `room_id`,
        `clean_date`,
        `status`,
        `cleaner_id`,
        `remarks`
    )
VALUES
    (4, CURDATE(), 2, 2, '客人刚退房，需要尽快清洁'),
    (1, CURDATE(), 1, NULL, '常规清洁');

-- 初始化维修任务数据
INSERT INTO
    `room_maintenance` (
        `room_id`,
        `issue_type`,
        `issue_desc`,
        `status`,
        `reporter_id`,
        `maintainer_id`
    )
VALUES
    (3, '水电', '水龙头漏水', 2, 1, 3),
    (1, '电器', '空调制冷效果差', 1, 1, NULL);

-- ==================================
-- 4、物资与库存管理模块
-- ==================================
-- 物资品类表
CREATE TABLE `inv_categories` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID',
    `category_name` varchar(50) NOT NULL COMMENT '分类名称',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '物资品类表';

-- 物资信息表
CREATE TABLE `inv_items` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '物资ID',
    `item_code` varchar(20) NOT NULL COMMENT '物资编码',
    `item_name` varchar(100) NOT NULL COMMENT '物资名称',
    `category_id` int(11) NOT NULL COMMENT '分类ID',
    `unit` varchar(10) NOT NULL COMMENT '单位',
    `min_stock` int(11) NOT NULL DEFAULT 0 COMMENT '最低库存',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_item_code` (`item_code`),
    KEY `idx_category` (`category_id`),
    CONSTRAINT `fk_item_category` FOREIGN KEY (`category_id`) REFERENCES `inv_categories` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '物资信息表';

-- 供应商表
CREATE TABLE `inv_suppliers` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '供应商ID',
    `supplier_name` varchar(100) NOT NULL COMMENT '供应商名称',
    `contact_person` varchar(50) DEFAULT NULL COMMENT '联系人',
    `contact_phone` varchar(20) DEFAULT NULL COMMENT '联系电话',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '供应商表';

-- 库存表
CREATE TABLE `inv_stock` (
    `item_id` int(11) NOT NULL COMMENT '物资ID',
    `quantity` int(11) NOT NULL DEFAULT 0 COMMENT '当前库存量',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    PRIMARY KEY (`item_id`),
    CONSTRAINT `fk_stock_item` FOREIGN KEY (`item_id`) REFERENCES `inv_items` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '库存表';

-- 入库/出库记录表
CREATE TABLE `inv_transactions` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '交易ID',
    `item_id` int(11) NOT NULL COMMENT '物资ID',
    `transaction_type` tinyint(1) NOT NULL COMMENT '类型(1:入库,2:出库)',
    `quantity` int(11) NOT NULL COMMENT '数量',
    `supplier_id` int(11) DEFAULT NULL COMMENT '供应商ID(入库时)',
    `department` varchar(50) DEFAULT NULL COMMENT '领用部门(出库时)',
    `operator_id` int(11) DEFAULT NULL COMMENT '操作人ID',
    `transaction_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '交易时间',
    `remarks` varchar(255) DEFAULT NULL COMMENT '备注',
    PRIMARY KEY (`id`),
    KEY `idx_item` (`item_id`),
    KEY `idx_supplier` (`supplier_id`),
    KEY `idx_transaction_time` (`transaction_time`),
    CONSTRAINT `fk_trans_item` FOREIGN KEY (`item_id`) REFERENCES `inv_items` (`id`) ON DELETE RESTRICT,
    CONSTRAINT `fk_trans_supplier` FOREIGN KEY (`supplier_id`) REFERENCES `inv_suppliers` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '入库/出库记录表';

-- 初始化物资与库存管理模块数据
-- 物资分类数据
INSERT INTO
    `inv_categories` (`category_name`, `status`)
VALUES
    ('客房用品', 1),
    ('清洁用品', 1),
    ('办公用品', 1),
    ('维修材料', 1);

-- 供应商数据
INSERT INTO
    `inv_suppliers` (
        `supplier_name`,
        `contact_person`,
        `contact_phone`,
        `status`
    )
VALUES
    ('某某酒店用品有限公司', '张经理', '13800138001', 1),
    ('某某清洁用品批发商', '李经理', '13900139002', 1);

-- 物资信息数据
INSERT INTO
    `inv_items` (
        `item_code`,
        `item_name`,
        `category_id`,
        `unit`,
        `min_stock`,
        `status`
    )
VALUES
    ('KF001', '毛巾', 1, '条', 100, 1),
    ('KF002', '一次性拖鞋', 1, '双', 150, 1),
    ('KF003', '洗发水', 1, '瓶', 80, 1),
    ('QJ001', '洗洁精', 2, '瓶', 20, 1),
    ('QJ002', '消毒液', 2, '瓶', 15, 1),
    ('WX001', '灯泡', 4, '个', 30, 1);

-- 初始库存数据
INSERT INTO
    `inv_stock` (`item_id`, `quantity`)
VALUES
    (1, 200),
    (2, 300),
    (3, 120),
    (4, 40),
    (5, 35),
    (6, 60);

-- 库存交易示例
INSERT INTO
    `inv_transactions` (
        `item_id`,
        `transaction_type`,
        `quantity`,
        `supplier_id`,
        `department`,
        `operator_id`,
        `remarks`
    )
VALUES
    (1, 1, 200, 1, NULL, 1, '初始采购入库'),
    (2, 1, 300, 1, NULL, 1, '初始采购入库'),
    (3, 2, 10, NULL, '客房部', 2, '日常补充');

-- 物资与库存管理相关功能说明:
-- 1. 库存交易表用于记录所有入库和出库操作，系统将根据这些记录计算当前库存
-- 2. 系统会根据最低库存设置进行低库存预警
-- 3. 其他额外操作通过sys_logs系统日志表记录，减少表数量
-- 4. 物资领用关联到部门而非特定房间，简化管理流程
-- 从这里开始
-- ==================================
-- 5、预订管理模块
-- ==================================
-- 预订渠道表
CREATE TABLE `booking_channels` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '渠道ID',
    `channel_name` varchar(50) NOT NULL COMMENT '渠道名称',
    `commission_rate` decimal(5, 2) DEFAULT 0.00 COMMENT '佣金比例(%)',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '预订渠道表';

-- 预订主表
CREATE TABLE `booking_orders` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '预订ID',
    `booking_no` varchar(20) NOT NULL COMMENT '预订号',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID',
    `guest_name` varchar(50) NOT NULL COMMENT '客人姓名',
    `guest_mobile` varchar(20) NOT NULL COMMENT '客人手机',
    `guest_email` varchar(100) DEFAULT NULL COMMENT '客人邮箱',
    `id_number` varchar(30) DEFAULT NULL COMMENT '证件号码',
    `channel_id` int(11) NOT NULL COMMENT '预订渠道ID',
    `arrival_date` date NOT NULL COMMENT '预计到店日期',
    `departure_date` date NOT NULL COMMENT '预计离店日期',
    `room_type_id` int(11) NOT NULL COMMENT '房型ID',
    `room_count` int(11) NOT NULL DEFAULT 1 COMMENT '房间数量',
    `room_rate` decimal(10, 2) NOT NULL COMMENT '房价',
    `breakfast` tinyint(1) NOT NULL DEFAULT 0 COMMENT '含早(0:不含,1:含单早,2:含双早)',
    `total_amount` decimal(10, 2) NOT NULL COMMENT '订单总金额',
    `paid_amount` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '已付金额',
    `special_request` varchar(500) DEFAULT NULL COMMENT '特殊要求',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单状态(1:待确认,2:已确认,3:已取消,4:已入住,5:已退房)',
    `create_by` int(11) DEFAULT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_booking_no` (`booking_no`),
    KEY `idx_member_id` (`member_id`),
    KEY `idx_channel_id` (`channel_id`),
    KEY `idx_dates` (`arrival_date`, `departure_date`),
    KEY `idx_status` (`status`),
    KEY `idx_room_type` (`room_type_id`),
    CONSTRAINT `fk_booking_member` FOREIGN KEY (`member_id`) REFERENCES `guest_members` (`id`) ON DELETE
    SET
        NULL,
        CONSTRAINT `fk_booking_channel` FOREIGN KEY (`channel_id`) REFERENCES `booking_channels` (`id`),
        CONSTRAINT `fk_booking_room_type` FOREIGN KEY (`room_type_id`) REFERENCES `room_types` (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '预订主表';

-- 预订房间表
CREATE TABLE `booking_rooms` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `booking_id` int(11) NOT NULL COMMENT '预订ID',
    `room_id` int(11) DEFAULT NULL COMMENT '分配的房间ID',
    `check_in_time` datetime DEFAULT NULL COMMENT '实际入住时间',
    `check_out_time` datetime DEFAULT NULL COMMENT '实际退房时间',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:预订,2:已入住,3:已退房,4:已取消)',
    PRIMARY KEY (`id`),
    KEY `idx_booking_id` (`booking_id`),
    KEY `idx_room_id` (`room_id`),
    CONSTRAINT `fk_booking_room_booking` FOREIGN KEY (`booking_id`) REFERENCES `booking_orders` (`id`) ON DELETE CASCADE,
    CONSTRAINT `fk_booking_room` FOREIGN KEY (`room_id`) REFERENCES `room_info` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '预订房间表';

-- 初始化预订管理模块数据
-- 预订渠道初始数据
INSERT INTO
    `booking_channels` (`channel_name`, `commission_rate`, `status`)
VALUES
    ('前台直接预订', 0.00, 1),
    ('官网预订', 0.00, 1),
    ('电话预订', 0.00, 1),
    ('携程旅行', 8.00, 1),
    ('美团酒店', 7.50, 1),
    ('飞猪旅行', 7.00, 1);

-- 预订示例数据
INSERT INTO
    `booking_orders` (
        `booking_no`,
        `member_id`,
        `guest_name`,
        `guest_mobile`,
        `guest_email`,
        `id_number`,
        `channel_id`,
        `arrival_date`,
        `departure_date`,
        `room_type_id`,
        `room_count`,
        `room_rate`,
        `breakfast`,
        `total_amount`,
        `paid_amount`,
        `special_request`,
        `status`,
        `create_by`
    )
VALUES
    (
        'BK20230601001',
        1,
        '张三',
        '13800138001',
        'zhangsan@example.com',
        '110101199001011234',
        1,
        '2023-06-01',
        '2023-06-03',
        3,
        1,
        488.00,
        2,
        976.00,
        0.00,
        '希望安排安静的房间，高楼层',
        2,
        1
    ),
    (
        'BK20230602001',
        2,
        '李四',
        '13800138002',
        'lisi@example.com',
        '110101199203034321',
        4,
        '2023-06-02',
        '2023-06-05',
        2,
        1,
        368.00,
        2,
        1104.00,
        1104.00,
        '需要婴儿床',
        2,
        1
    ),
    (
        'BK20230605001',
        NULL,
        '王五',
        '13800138003',
        NULL,
        '110101199505055678',
        5,
        '2023-06-05',
        '2023-06-06',
        2,
        1,
        328.00,
        2,
        328.00,
        328.00,
        NULL,
        1,
        2
    );

-- 预订房间示例数据
INSERT INTO
    `booking_rooms` (`booking_id`, `room_id`, `status`)
VALUES
    (1, NULL, 1),
    (2, 2, 1),
    (3, NULL, 1);

-- 预订管理模块相关功能说明:
-- 1. 减少了表的数量，从原来的6个表减少到3个表，删除了房价方案表、状态变更日志表和提醒表
-- 2. 将房价方案的关键信息直接整合到booking_orders表中，简化关系
-- 3. 删除了一些不必要的字段，如证件类型、操作人等信息可以在日志中记录
-- 4. 预订状态变更等审计信息可以通过sys_logs系统日志表记录，不需要单独的表
-- 5. 提醒功能可以通过程序逻辑实现，不需要单独的表存储
-- 6. 修改了表前缀为booking_，统一命名规范
-- ==================================
-- 6、入住与退房管理模块
-- ==================================
-- 入住登记表
CREATE TABLE `checkin_orders` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '入住ID',
    `checkin_no` varchar(20) NOT NULL COMMENT '入住单号',
    `booking_id` int(11) DEFAULT NULL COMMENT '关联预订ID',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID',
    `guest_name` varchar(50) NOT NULL COMMENT '客人姓名',
    `guest_mobile` varchar(20) NOT NULL COMMENT '客人手机',
    `id_number` varchar(30) NOT NULL COMMENT '证件号码',
    `room_id` int(11) NOT NULL COMMENT '房间ID',
    `checkin_time` datetime NOT NULL COMMENT '入住时间',
    `checkout_time` datetime DEFAULT NULL COMMENT '退房时间',
    `room_rate` decimal(10, 2) NOT NULL COMMENT '房价',
    `deposit_amount` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '押金金额',
    `total_amount` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '消费总金额',
    `has_damage` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否有损坏',
    `damage_amount` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '损坏赔偿金额',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:在住,2:已退房,3:已取消)',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_by` int(11) DEFAULT NULL COMMENT '操作员ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_checkin_no` (`checkin_no`),
    KEY `idx_booking_id` (`booking_id`),
    KEY `idx_member_id` (`member_id`),
    KEY `idx_room_id` (`room_id`),
    KEY `idx_status` (`status`),
    CONSTRAINT `fk_checkin_booking` FOREIGN KEY (`booking_id`) REFERENCES `booking_orders` (`id`) ON DELETE
    SET
        NULL,
        CONSTRAINT `fk_checkin_member` FOREIGN KEY (`member_id`) REFERENCES `guest_members` (`id`) ON DELETE
    SET
        NULL,
        CONSTRAINT `fk_checkin_room` FOREIGN KEY (`room_id`) REFERENCES `room_info` (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '入住登记表';

-- 同住人表
CREATE TABLE `checkin_guests` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `checkin_id` int(11) NOT NULL COMMENT '入住ID',
    `guest_name` varchar(50) NOT NULL COMMENT '客人姓名',
    `id_number` varchar(30) NOT NULL COMMENT '证件号码',
    PRIMARY KEY (`id`),
    KEY `idx_checkin_id` (`checkin_id`),
    CONSTRAINT `fk_guest_checkin` FOREIGN KEY (`checkin_id`) REFERENCES `checkin_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '同住人表';

-- 消费与押金记录表
CREATE TABLE `checkin_transactions` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `checkin_id` int(11) NOT NULL COMMENT '入住ID',
    `type` tinyint(1) NOT NULL COMMENT '类型(1:房费,2:餐饮,3:其他消费,4:押金收取,5:押金退还,6:押金扣除)',
    `amount` decimal(10, 2) NOT NULL COMMENT '金额',
    `payment_method` tinyint(1) DEFAULT NULL COMMENT '支付方式(1:现金,2:信用卡,3:微信,4:支付宝)',
    `transaction_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '交易时间',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `operator_id` int(11) DEFAULT NULL COMMENT '操作员ID',
    PRIMARY KEY (`id`),
    KEY `idx_checkin_id` (`checkin_id`),
    KEY `idx_type` (`type`),
    CONSTRAINT `fk_transaction_checkin` FOREIGN KEY (`checkin_id`) REFERENCES `checkin_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '消费与押金记录表';

-- 发票表（简化版）
CREATE TABLE `checkin_invoices` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '发票ID',
    `checkin_id` int(11) NOT NULL COMMENT '入住ID',
    `invoice_no` varchar(30) NOT NULL COMMENT '发票号码',
    `title` varchar(100) NOT NULL COMMENT '发票抬头',
    `amount` decimal(10, 2) NOT NULL COMMENT '金额',
    `content` varchar(255) NOT NULL COMMENT '发票内容',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:待开票,2:已开票,3:已作废)',
    `issue_time` datetime DEFAULT NULL COMMENT '开票时间',
    `operator_id` int(11) DEFAULT NULL COMMENT '操作员ID',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_invoice_no` (`invoice_no`),
    KEY `idx_checkin_id` (`checkin_id`),
    CONSTRAINT `fk_invoice_checkin` FOREIGN KEY (`checkin_id`) REFERENCES `checkin_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '发票表';

-- 初始化入住与退房管理模块数据
-- 入住登记示例数据
INSERT INTO
    `checkin_orders` (
        `checkin_no`,
        `booking_id`,
        `member_id`,
        `guest_name`,
        `guest_mobile`,
        `id_number`,
        `room_id`,
        `checkin_time`,
        `checkout_time`,
        `room_rate`,
        `deposit_amount`,
        `status`,
        `create_by`
    )
VALUES
    (
        'CI20230601001',
        1,
        1,
        '张三',
        '13800138001',
        '110101199001011234',
        3,
        '2023-06-01 14:30:00',
        NULL,
        488.00,
        500.00,
        1,
        1
    ),
    (
        'CI20230602001',
        2,
        2,
        '李四',
        '13800138002',
        '110101199203034321',
        2,
        '2023-06-02 15:00:00',
        NULL,
        368.00,
        500.00,
        1,
        1
    ),
    (
        'CI20230520001',
        NULL,
        3,
        '王五',
        '13800138003',
        '110101199505055678',
        1,
        '2023-05-20 16:00:00',
        '2023-05-22 11:30:00',
        288.00,
        300.00,
        2,
        2
    );

-- 同住人示例数据
INSERT INTO
    `checkin_guests` (`checkin_id`, `guest_name`, `id_number`)
VALUES
    (1, '张小三', '110101199501011234'),
    (2, '李小四', '110101199603034321');

-- 消费与押金记录示例数据
INSERT INTO
    `checkin_transactions` (
        `checkin_id`,
        `type`,
        `amount`,
        `payment_method`,
        `transaction_time`,
        `remark`,
        `operator_id`
    )
VALUES
    (
        1,
        4,
        500.00,
        2,
        '2023-06-01 14:30:00',
        '入住缴纳押金',
        1
    ),
    (
        1,
        1,
        488.00,
        2,
        '2023-06-01 14:30:00',
        '第一晚房费',
        1
    ),
    (1, 2, 58.00, 2, '2023-06-02 08:30:00', '两份早餐', 3),
    (
        2,
        4,
        500.00,
        3,
        '2023-06-02 15:00:00',
        '入住缴纳押金',
        1
    ),
    (
        2,
        1,
        368.00,
        3,
        '2023-06-02 15:00:00',
        '第一晚房费',
        1
    ),
    (
        3,
        4,
        300.00,
        1,
        '2023-05-20 16:00:00',
        '入住缴纳押金',
        2
    ),
    (
        3,
        1,
        576.00,
        1,
        '2023-05-20 16:00:00',
        '两晚房费',
        2
    ),
    (
        3,
        5,
        300.00,
        1,
        '2023-05-22 11:30:00',
        '退房退还押金',
        2
    );
-- 发票示例数据
INSERT INTO
    `checkin_invoices` (
        `checkin_id`,
        `invoice_no`,
        `title`,
        `amount`,
        `content`,
        `status`,
        `issue_time`,
        `operator_id`
    )
VALUES
    (
        3,
        'INV20230522001',
        '王五',
        576.00,
        '住宿费',
        2,
        '2023-05-22 11:40:00',
        2
    );
-- 入住与退房管理模块相关功能说明:
-- 1. 大幅简化了表结构，从原来的6个表减少到3个核心表
-- 2. 将押金记录和费用明细合并为统一的交易表(checkin_transactions)，通过type字段区分不同类型
-- 3. 将房间检查信息整合到主表，只保留基本的损坏信息
-- 4. 删除了证件类型等冗余字段，简化数据结构
-- 5. 精简了字段名称，如planned_checkout_time改为checkout_time
-- 6. 添加了简化版的发票表，只保留核心字段，与入住记录关联
-- ==================================
-- 8、OTA及渠道管理模块
-- ==================================
-- OTA渠道表
CREATE TABLE `ota_channels` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'OTA渠道ID',
    `channel_code` varchar(20) NOT NULL COMMENT '渠道代码',
    `channel_name` varchar(50) NOT NULL COMMENT '渠道名称',
    `commission_rate` decimal(5, 2) NOT NULL DEFAULT 0.00 COMMENT '佣金比例(%)',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_channel_code` (`channel_code`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = 'OTA渠道表';

-- OTA房价表
CREATE TABLE `ota_room_rates` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `channel_id` int(11) NOT NULL COMMENT 'OTA渠道ID',
    `room_type_id` int(11) NOT NULL COMMENT '房型ID',
    `date` date NOT NULL COMMENT '日期',
    `price` decimal(10, 2) NOT NULL COMMENT '房价',
    `inventory` int(11) NOT NULL DEFAULT 0 COMMENT '可售数量',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:停售,1:可售)',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_channel_room_date` (`channel_id`, `room_type_id`, `date`),
    KEY `idx_room_type` (`room_type_id`),
    CONSTRAINT `fk_ota_channel` FOREIGN KEY (`channel_id`) REFERENCES `ota_channels` (`id`),
    CONSTRAINT `fk_ota_room_type` FOREIGN KEY (`room_type_id`) REFERENCES `room_types` (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = 'OTA房价表';

-- 初始化OTA及渠道管理模块数据
-- OTA渠道示例数据
INSERT INTO
    `ota_channels` (
        `channel_code`,
        `channel_name`,
        `commission_rate`,
        `status`
    )
VALUES
    ('ctrip', '携程旅行', 8.00, 1),
    ('fliggy', '飞猪旅行', 7.00, 1),
    ('meituan', '美团旅行', 7.50, 1);

-- OTA房价示例数据
INSERT INTO
    `ota_room_rates` (
        `channel_id`,
        `room_type_id`,
        `date`,
        `price`,
        `inventory`,
        `status`
    )
VALUES
    (
        1,
        2,
        DATE_ADD(CURDATE(), INTERVAL 1 DAY),
        388.00,
        5,
        1
    );

-- OTA及渠道管理模块相关功能说明:
-- 1. OTA渠道表存储第三方在线旅行平台的基本信息
-- 2. OTA房价表管理每个渠道在不同日期的房型价格和可售库存
-- 3. 简化版设计仅保留核心字段，满足基本功能需求
-- ==================================
-- 9、财务与结算管理模块
-- ==================================
-- 收支记录表
CREATE TABLE `finance_payments` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '支付ID',
    `payment_no` varchar(30) NOT NULL COMMENT '支付单号',
    `type` tinyint(1) NOT NULL COMMENT '类型(1:收款,2:退款)',
    `booking_id` int(11) DEFAULT NULL COMMENT '预订ID',
    `checkin_id` int(11) DEFAULT NULL COMMENT '入住ID',
    `amount` decimal(10, 2) NOT NULL COMMENT '金额',
    `payment_method` tinyint(1) NOT NULL COMMENT '支付方式(1:现金,2:信用卡,3:微信,4:支付宝,5:银行转账)',
    `payment_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '支付时间',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:已支付,2:已退款,3:已取消)',
    `operator_id` int(11) DEFAULT NULL COMMENT '操作员ID',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_payment_no` (`payment_no`),
    KEY `idx_booking_id` (`booking_id`),
    KEY `idx_checkin_id` (`checkin_id`),
    CONSTRAINT `fk_payment_booking` FOREIGN KEY (`booking_id`) REFERENCES `booking_orders` (`id`) ON DELETE
    SET
        NULL,
        CONSTRAINT `fk_payment_checkin` FOREIGN KEY (`checkin_id`) REFERENCES `checkin_orders` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '收支记录表';

-- OTA佣金表
CREATE TABLE `finance_commissions` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '佣金ID',
    `channel_id` int(11) NOT NULL COMMENT 'OTA渠道ID',
    `booking_id` int(11) NOT NULL COMMENT '预订ID',
    `amount` decimal(10, 2) NOT NULL COMMENT '订单金额',
    `commission_rate` decimal(5, 2) NOT NULL COMMENT '佣金比例(%)',
    `commission_amount` decimal(10, 2) NOT NULL COMMENT '佣金金额',
    `settlement_status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '结算状态(1:未结算,2:已结算)',
    `settlement_time` datetime DEFAULT NULL COMMENT '结算时间',
    `settlement_batch` varchar(30) DEFAULT NULL COMMENT '结算批次号',
    PRIMARY KEY (`id`),
    KEY `idx_channel_id` (`channel_id`),
    KEY `idx_booking_id` (`booking_id`),
    KEY `idx_settlement_batch` (`settlement_batch`),
    CONSTRAINT `fk_commission_channel` FOREIGN KEY (`channel_id`) REFERENCES `ota_channels` (`id`),
    CONSTRAINT `fk_commission_booking` FOREIGN KEY (`booking_id`) REFERENCES `booking_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = 'OTA佣金表';

-- 初始化财务与结算管理模块数据
-- 收支记录示例数据
INSERT INTO
    `finance_payments` (
        `payment_no`,
        `type`,
        `booking_id`,
        `checkin_id`,
        `amount`,
        `payment_method`,
        `payment_time`,
        `status`,
        `operator_id`,
        `remark`
    )
VALUES
    (
        'PAY20230530001',
        1,
        2,
        NULL,
        1104.00,
        3,
        '2023-05-30 15:20:00',
        1,
        1,
        '预订订金全额支付'
    ),
    (
        'PAY20230601001',
        1,
        NULL,
        1,
        488.00,
        2,
        '2023-06-01 14:30:00',
        1,
        1,
        '入住房费支付'
    ),
    (
        'PAY20230602001',
        2,
        3,
        NULL,
        328.00,
        4,
        '2023-06-02 16:40:00',
        2,
        2,
        '取消预订退款'
    );

-- OTA佣金示例数据
INSERT INTO
    `finance_commissions` (
        `channel_id`,
        `booking_id`,
        `amount`,
        `commission_rate`,
        `commission_amount`,
        `settlement_status`,
        `settlement_time`,
        `settlement_batch`
    )
VALUES
    (
        4,
        2,
        1104.00,
        8.00,
        88.32,
        2,
        '2023-05-31 23:59:59',
        'COMM202305'
    );

-- 财务与结算管理模块相关功能说明:
-- 1. 收支记录表统一管理所有收款和退款操作，支持与预订单或入住单关联
-- 2. OTA佣金表记录第三方平台订单的佣金计算和结算情况
-- 3. 系统通过这两个表可以生成财务报表，如每日/每月/每年收入统计
-- 4. 支持多种支付方式，包括微信、支付宝、信用卡、现金和银行转账
-- 5. 简化设计仅保留核心字段，满足基本财务管理需求
-- ==================================
-- 10、统计与报表模块
-- ==================================
-- 每日统计数据表
CREATE TABLE `report_daily_statistics` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `stat_date` date NOT NULL COMMENT '统计日期',
    `available_rooms` int(11) NOT NULL COMMENT '可用房间数',
    `occupied_rooms` int(11) NOT NULL COMMENT '已住房间数',
    `occupancy_rate` decimal(5, 2) NOT NULL COMMENT '入住率(%)',
    `avg_room_rate` decimal(10, 2) NOT NULL COMMENT '平均房价',
    `total_revenue` decimal(12, 2) NOT NULL COMMENT '当日总收入',
    `room_revenue` decimal(12, 2) NOT NULL COMMENT '房费收入',
    `other_revenue` decimal(12, 2) NOT NULL COMMENT '其他收入',
    `refund_amount` decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '退款金额',
    `new_bookings` int(11) NOT NULL DEFAULT 0 COMMENT '新增预订数',
    `cancelled_bookings` int(11) NOT NULL DEFAULT 0 COMMENT '取消预订数',
    `checkins` int(11) NOT NULL DEFAULT 0 COMMENT '入住数',
    `checkouts` int(11) NOT NULL DEFAULT 0 COMMENT '退房数',
    `ota_bookings` int(11) NOT NULL DEFAULT 0 COMMENT 'OTA预订数',
    `calc_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '计算时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_stat_date` (`stat_date`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '每日统计数据表';

-- 月度统计数据表
CREATE TABLE `report_monthly_statistics` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `year` smallint(4) NOT NULL COMMENT '年份',
    `month` tinyint(2) NOT NULL COMMENT '月份',
    `available_room_nights` int(11) NOT NULL COMMENT '可用房晚数',
    `occupied_room_nights` int(11) NOT NULL COMMENT '已住房晚数',
    `occupancy_rate` decimal(5, 2) NOT NULL COMMENT '入住率(%)',
    `avg_room_rate` decimal(10, 2) NOT NULL COMMENT '平均房价',
    `revpar` decimal(10, 2) NOT NULL COMMENT '每可用房收益',
    `total_revenue` decimal(12, 2) NOT NULL COMMENT '月度总收入',
    `room_revenue` decimal(12, 2) NOT NULL COMMENT '房费收入',
    `other_revenue` decimal(12, 2) NOT NULL COMMENT '其他收入',
    `booking_cancellation_rate` decimal(5, 2) NOT NULL COMMENT '预订取消率(%)',
    `ota_contribution_rate` decimal(5, 2) NOT NULL COMMENT 'OTA贡献率(%)',
    `calc_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '计算时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_year_month` (`year`, `month`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '月度统计数据表';

-- 自定义报表表
CREATE TABLE `report_saved_reports` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '报表ID',
    `report_name` varchar(100) NOT NULL COMMENT '报表名称',
    `report_type` tinyint(1) NOT NULL COMMENT '报表类型(1:入住率,2:营收,3:渠道分析,4:客户分析)',
    `report_params` text NOT NULL COMMENT '报表参数(JSON格式)',
    `chart_type` varchar(20) DEFAULT NULL COMMENT '图表类型(line,bar,pie等)',
    `is_public` tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否公开(0:私有,1:公开)',
    `create_by` int(11) NOT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `last_run_time` datetime DEFAULT NULL COMMENT '最后运行时间',
    PRIMARY KEY (`id`),
    KEY `idx_create_by` (`create_by`),
    KEY `idx_report_type` (`report_type`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '自定义报表表';

-- 初始化统计与报表模块数据
-- 每日统计示例数据
INSERT INTO
    `report_daily_statistics` (
        `stat_date`,
        `available_rooms`,
        `occupied_rooms`,
        `occupancy_rate`,
        `avg_room_rate`,
        `total_revenue`,
        `room_revenue`,
        `other_revenue`,
        `refund_amount`,
        `new_bookings`,
        `cancelled_bookings`,
        `checkins`,
        `checkouts`,
        `ota_bookings`,
        `calc_time`
    )
VALUES
    (
        '2023-05-30',
        100,
        68,
        68.00,
        420.50,
        32560.00,
        28594.00,
        3966.00,
        1200.00,
        15,
        2,
        22,
        18,
        8,
        '2023-05-31 01:00:00'
    ),
    (
        '2023-05-31',
        100,
        72,
        72.00,
        435.25,
        35680.00,
        31338.00,
        4342.00,
        600.00,
        18,
        1,
        24,
        20,
        10,
        '2023-06-01 01:00:00'
    ),
    (
        '2023-06-01',
        100,
        85,
        85.00,
        452.80,
        42860.00,
        38488.00,
        4372.00,
        850.00,
        22,
        3,
        28,
        15,
        12,
        '2023-06-02 01:00:00'
    ),
    (
        '2023-06-02',
        100,
        90,
        90.00,
        468.50,
        46850.00,
        42165.00,
        4685.00,
        328.00,
        12,
        2,
        18,
        13,
        6,
        '2023-06-03 01:00:00'
    );

-- 月度统计示例数据
INSERT INTO
    `report_monthly_statistics` (
        `year`,
        `month`,
        `available_room_nights`,
        `occupied_room_nights`,
        `occupancy_rate`,
        `avg_room_rate`,
        `revpar`,
        `total_revenue`,
        `room_revenue`,
        `other_revenue`,
        `booking_cancellation_rate`,
        `ota_contribution_rate`
    )
VALUES
    (
        2023,
        4,
        3000,
        2184,
        72.80,
        432.50,
        315.06,
        1058600.00,
        944580.00,
        114020.00,
        4.80,
        35.20
    ),
    (
        2023,
        5,
        3100,
        2418,
        78.00,
        445.75,
        347.69,
        1195320.00,
        1077823.80,
        117496.20,
        3.90,
        37.50
    );

-- 自定义报表示例数据
INSERT INTO
    `report_saved_reports` (
        `report_name`,
        `report_type`,
        `report_params`,
        `chart_type`,
        `is_public`,
        `create_by`,
        `last_run_time`
    )
VALUES
    (
        '2023年上半年入住率趋势分析',
        1,
        '{"start_date":"2023-01-01","end_date":"2023-06-30","room_types":[1,2,3],"compare_last_year":true}',
        'line',
        1,
        1,
        '2023-06-01 10:15:22'
    ),
    (
        '各渠道订单贡献度分析',
        3,
        '{"start_date":"2023-04-01","end_date":"2023-05-31","group_by":"channel"}',
        'pie',
        1,
        1,
        '2023-06-01 14:30:45'
    ),
    (
        '客户等级统计与消费分析',
        4,
        '{"start_date":"2023-01-01","end_date":"2023-05-31","group_by":"level"}',
        'bar',
        0,
        4,
        '2023-05-25 16:40:12'
    );

-- 统计与报表模块相关功能说明:
-- 1. 每日统计数据表存储系统自动计算的每日运营数据，用于生成日报表
-- 2. 月度统计数据表存储系统自动汇总的月度运营数据，用于分析月度趋势和业绩
-- 3. 自定义报表表允许用户保存常用报表的配置，以便快速生成报表
-- 4. 系统也可以基于现有业务数据表直接查询生成实时报表
-- 5. 报表中的各项具体指标包括：
--    - 入住率 = 已住房间数 / 可用房间数 × 100%
--    - RevPAR(每可用房收益) = 房费收入 / 可用房间数
--    - 预订取消率 = 取消预订数 / 总预订数 × 100%
--    - OTA贡献率 = OTA渠道预订数 / 总预订数 × 100%